package com.gestionnaires;

import java.util.Vector;
import com.articles.Article;
import com.articles.Categorie;

/**
 * Gestionnaire des articles (et des catgories) :<br>
 * Rcupre les articles et les catgories depuis la BDD, selon des critres ou non.<br>
 * Note : il ne doit y avoir qu'une instance de cette classe : elle utilise le gestionnaire de connexion  la BDD.
 * @author 3fvorillion
 */
public class GestionnaireArticles
{
	private static GestionnaireArticles instanceUnique = null;
	private GestionConnexion gestConn = null;
	private ParametresConnexion paramsConn = null;

	/**
	 * Instancie le gestionnaire d'articles.<br>
	 * - instancie le gestionnaire de connexion  la BDD.
	 * @throws Exception
	 */
	public GestionnaireArticles()
		throws Exception
	{
		//
		// Cration de l'objet connexion
		//
		this.gestConn = new GestionConnexion();
		
		this.paramsConn = new ParametresConnexion();
	}

	/***
	 * Donne la liste des articles correspondants aux conditions donnees.
	 * @param sConditions Conditions de selection des articles.<br>Peut tre null ou vide.<br>Sans la clause 'where'.
	 * @return Liste des articles correspondants aux critres donns.
	 */
	public Vector<Article> donnerListeArticles(String sConditions)
		throws Exception
	{
		Vector<Vector<Object>> vResReq = null;
		Vector<String> vLstCols = null;
		Vector<Article> vLstArts = null;
		Article tmpArt = null;
		String sReqSQL = "";

		//
		// Se connecte  la base
		//
		// Ouvre la connexion si pas dj fait
		if (!this.gestConn.estOuverte())
			this.gestConn.ouvrir(this.paramsConn);

		// Si pas ouverte, sort
		if ( !this.gestConn.estOuverte() )
			throw new Exception("La connexion avec la base de donnes n'a pas pu tre tablie.");

		//
		// Crer la requte
		//
		sReqSQL = "SELECT * FROM ARTICLES_RANDO";
		if (sConditions != null)
			if (!sConditions.equals(""))
				sReqSQL += " WHERE " + sConditions;
		
		//
		// Lance la requte et rcupre les donnes
		//
		if (this.gestConn.lancerRequeteSelection(sReqSQL))
		{
			vResReq = this.gestConn.getDataVector();
			vLstCols = this.gestConn.getNomsColonnes();
			vLstArts = new Vector<Article>(vResReq.size());

			for (int iArt=0; iArt<vResReq.size(); iArt++)
			{
				tmpArt = new Article();

				//Rcupre les donnes
				for (int iCol=0; iCol<vLstCols.size(); iCol++)
				{
					if (vLstCols.get(iCol).toUpperCase().equals("REFERENCE"))
						tmpArt.setRef(String.valueOf(vResReq.get(iArt).get(iCol)));
					else if (vLstCols.get(iCol).toUpperCase().equals("CATEGORIE"))
						tmpArt.setCateg(String.valueOf(vResReq.get(iArt).get(iCol)));
					else if (vLstCols.get(iCol).toUpperCase().equals("MARQUE"))
						tmpArt.setMarque(String.valueOf(vResReq.get(iArt).get(iCol)));
					else if (vLstCols.get(iCol).toUpperCase().equals("MODELE"))
						tmpArt.setModele(String.valueOf(vResReq.get(iArt).get(iCol)));
					else if (vLstCols.get(iCol).toUpperCase().equals("PRIX"))
						tmpArt.setPrix(Double.parseDouble(vResReq.get(iArt).get(iCol).toString()));
					else if (vLstCols.get(iCol).toUpperCase().equals("PHOTO"))
						tmpArt.setPhoto(String.valueOf(vResReq.get(iArt).get(iCol)));
					else if (vLstCols.get(iCol).toUpperCase().equals("DESCRIPTION"))
						tmpArt.setDescription(String.valueOf(vResReq.get(iArt).get(iCol)));
				}
				
				//Ajoute  la liste
				vLstArts.add(tmpArt);
			}
		}

		//
		// Se dconnecte de la base
		//
		// Ferme la connexion
		this.gestConn.fermerConnexion();

		return vLstArts;
	}

	/***
	 * Donne la liste des categories correspondants aux conditions donnees.
	 * @param sConditions Conditions de selection des categories.<br>Peut tre null ou vide.<br>Sans la clause 'where'.
	 * @return Liste des categories correspondants aux critres donns.
	 */
	public Vector<Categorie> donnerListeCategories(String sConditions)
		throws Exception
	{
		Vector<Vector<Object>> vResReq = null;
		Vector<String> vLstCols = null;
		Vector<Categorie> vLstCats = null;
		Categorie tmpCat = null;
		String sReqSQL = "";

		//
		// Se connecte  la base
		//
		// Ouvre la connexion si pas dj fait
		if (!this.gestConn.estOuverte())
			this.gestConn.ouvrir(this.paramsConn);

		// Si pas ouverte, sort
		if ( !this.gestConn.estOuverte() )
			throw new Exception("La connexion avec la base de donnes n'a pas pu tre tablie.");

		//
		// Crer la requte
		//
		sReqSQL = "SELECT * FROM CATEGORIE_RANDO";
		if (sConditions != null)
			if (!sConditions.equals(""))
				sReqSQL += " WHERE " + sConditions;
		
		//
		// Lance la requte et rcupre les donnes
		//
		if (this.gestConn.lancerRequeteSelection(sReqSQL))
		{
			vResReq = this.gestConn.getDataVector();
			vLstCols = this.gestConn.getNomsColonnes();
			vLstCats = new Vector<Categorie>(vResReq.size());

			for (int iArt=0; iArt<vResReq.size(); iArt++)
			{
				tmpCat = new Categorie();

				//Rcupre les donnes
				for (int iCol=0; iCol<vLstCols.size(); iCol++)
				{
					if (vLstCols.get(iCol).toUpperCase().equals("ID"))
						tmpCat.setId(Integer.parseInt(vResReq.get(iArt).get(iCol).toString()));
					else if (vLstCols.get(iCol).toUpperCase().equals("CAT"))
						tmpCat.setCat(String.valueOf(vResReq.get(iArt).get(iCol)));
				}
				
				//Ajoute  la liste
				vLstCats.add(tmpCat);
			}
		}

		//
		// Se dconnecte de la base
		//
		// Ferme la connexion
		this.gestConn.fermerConnexion();

		return vLstCats;
	}
	
	/**
	 * Retourne une instance unique pour le gestionnaire des articles.
	 * @return instance unique du gestionnaire des articles.
	 * @throws Exception
	 */
	public static GestionnaireArticles getInstanceUnique()
		throws Exception
	{
		if (GestionnaireArticles.instanceUnique == null)
			GestionnaireArticles.instanceUnique = new GestionnaireArticles();

		return GestionnaireArticles.instanceUnique;
	}
	
	/**
	 * Modifie l'instance unique pour le gestionnaire des articles.
	 * @param instanceUnique
	 */
	public static void setInstanceUnique(GestionnaireArticles instanceUnique)
	{
		if (instanceUnique == null)
			return;

		GestionnaireArticles.instanceUnique = instanceUnique;
	}
}
