package com.gestionnaires;

import java.util.Vector;
import com.articles.Article;

/**
 * Traite le contenu du panier.
 * @author 3fvorillion
 */
public class GestionnairePanier
{
	Vector<Article> vArticles = null;
	boolean bEstPaye = false;
	
	/**
	 * Instancie le panier
	 */
	public GestionnairePanier()
	{
		this.vArticles = new Vector<Article>();
	}
	
	/**
	 * Ajoute un article au panier.
	 * @param art article  ajouter.
	 */
	public void ajouterAchat(Article art)
	{
		Article artPan = null;
		boolean bArtTrouve = false;

		if (art == null)
			return;
		
		//Vrifie si pas dj prsent
		for (int i=0; i<this.vArticles.size() && !bArtTrouve; i++)
			if (this.vArticles.get(i).getRef().equals(art.getRef()))
			{
				artPan = this.vArticles.get(i);
				bArtTrouve = true;
			}

		//Si trouv, incrmente
		if (bArtTrouve)
			artPan.setQuantite(artPan.getQuantite()+1);
		//sinon, ajoute et met  jour la quantiti
		else
		{
			art.setQuantite(1);
			this.vArticles.add(art);
		}
	}
	
	/**
	 * Modifie la quantit pour un article de rfrence donne.
	 * @param sRefArticle Rfrence vers l'article.
	 * @param quantite Nouvelle quantit
	 */
	public void modifieAchat(String sRefArticle, int quantite)
	{
		for (int i=0; i<this.vArticles.size(); i++)
			if (this.vArticles.get(i).getRef().equals(sRefArticle))
				this.vArticles.get(i).setQuantite(quantite);
	}
	
	/**
	 * Enlve du panier l'article de rfrence donne 
	 * @param sRefArticle Rfrence vers l'article.
	 */
	public void enleverAchat(String sRefArticle)
	{
		for (int i=0; i<this.vArticles.size(); i++)
			if (this.vArticles.get(i).getRef().equals(sRefArticle))
				this.vArticles.remove(i);
	}
	
	/**
	 * Donne les articles du panier.
	 * @return liste des articles du panier.
	 */
	public Vector<Article> donneContenu()
	{
		return this.vArticles;
	}

	/**
	 * Donne l'tat de payement du panier.
	 * @return 'true' si le panier est pass ' la caisse'. 'fase' sinon.
	 */
	public boolean getEstPaye()
	{
		return this.bEstPaye;
	}

	/**
	 * Dtermine l'tat de payement du panier.
	 * @param bEstPaye 'true' si le panier est pass ' la caisse'. 'fase' sinon.
	 */
	public void setEstPaye(boolean bEstPaye)
	{
		this.bEstPaye = bEstPaye;
	}
	
	/**
	 * Calcule et retourne le prix total du panier.
	 * @return Prix total du panier.
	 */
	public double getPrixTotalPanier()
	{
		double prixTotal = 0;

		for (int i=0; i<this.vArticles.size(); i++)
			prixTotal += this.vArticles.get(i).getPrix() * this.vArticles.get(i).getQuantite();

		return prixTotal;
	}
}
