/*
 * Panier.java
 *
 * Created on 11 janvier 2008, 15:06
 */

package com.servlets;

import java.io.*;

import javax.servlet.*;
import javax.servlet.http.*;

import java.lang.*;
import java.util.Vector;
import com.articles.Article;
import com.articles.Panier;
import com.gestionnaires.Erreur;
import com.gestionnaires.GestionnairePanier;

/**
 * Servlet Grant l'affichage des articles du panier.<br>
 * - affichage des articles et de leurs caractristiques.
 * - modification des quantits.
 * - suppression des articles du panier.
 * @author 3fvorillion
 * @version
 */
public class PanierServlet
        extends HttpServlet
{
    com.gestionnaires.GestionnaireArticles gestArts = null;
    
    /**
     * Rcupre le panier courant de la session courante.<br>
     * Si pas de panier disponibles, en cr un.<br>
     * Si le painier courant en dj pay, en cr un autre.
     * @param request requete du servlet
     * @return le panier courant de la session
     */
    public static GestionnairePanier getPanierSession(HttpServletRequest request)
    {
    	HttpSession session = request.getSession(true);

    	//
    	// Rcupre l'objet de la session
    	//
    	GestionnairePanier panier = (GestionnairePanier)session.getAttribute("caddy");
    	if ( panier == null )
    	{
    		panier = new GestionnairePanier();
    		panier.setEstPaye(false);
    		
    		session.setAttribute("caddy", panier) ;
    	}
    	else if ( panier.getEstPaye() )
    	{
    		//Supprime l'ancien de la liste de la session
    		session.removeAttribute("caddy") ;

    		//Cr un nouveau
    		panier = new GestionnairePanier();
    		panier.setEstPaye(false);
    		
    		session.setAttribute("caddy", panier) ;
    	}
    		
    	
    	return panier;
    }
    
    /**
     * Traite les messages et affiche en consquence.
     * @param request
     * @param response
     * @throws ServletException
     * @throws IOException
     */
    private void affArticlesPanier(HttpServletRequest request, HttpServletResponse response)
    	throws ServletException, IOException
    {
    	GestionnairePanier panier = null;
    	Vector<Article> vArts = null;
    	String sAction;
    	String sPageAffichage;
    	String sCondReqSQL;

    	//
    	// Rcupre l'objet de la session
    	//
    	panier = PanierServlet.getPanierSession(request);

    	//
    	// Traite les actions
    	//
    	sAction = request.getParameter("action");
    	if (sAction == null)
    	{ ; }
    	else if (sAction.equals("add"))
    	{
    		if (request.getParameter("artRef") != null)
    		{
    			sCondReqSQL = "REFERENCE = '" + request.getParameter("artRef") + "'"; 

    			//Rcupre le gestionnaire d'articles
    	    	try
    	    	{
    	    		//
    	    		// Rcupre les articles depuis la base
    	    		//
    	    		this.gestArts = com.gestionnaires.GestionnaireArticles.getInstanceUnique();

    	        	//Rcupre la liste des articles
    	        	vArts = this.gestArts.donnerListeArticles(sCondReqSQL);

    	        	if (vArts.size() == 1)
    	        	{
    	    			panier.ajouterAchat(vArts.get(0));
    	        	}
    	        	else
    	        	{
    	        		Vector<Erreur> vErrs = new Vector<Erreur>();
    	        		if (vArts.isEmpty())
    	        			vErrs.add(new Erreur("Aucun article n'est disponible dans la boutique"));
    	        		else
    	        			vErrs.add(new Erreur("Trop d'articles correspondent  la slection"));
    	    	        request.setAttribute("erreurs", vErrs);
    	            
    	    	        sPageAffichage = "/erreurs.jsp";

        		        ServletContext ctx = getServletContext();
        		        RequestDispatcher rd = ctx.getRequestDispatcher(sPageAffichage);
        		        rd.forward(request,response);
        		        return;
    	    		}
    	    	}
    	    	catch (Exception ex)
    	    	{
    	    		Vector<Erreur> vErrs = new Vector<Erreur>();
    	    		vErrs.add(new Erreur(ex.getMessage()));
    		        request.setAttribute("erreurs", vErrs);
    	        
    		        sPageAffichage = "/erreurs.jsp";

    		        ServletContext ctx = getServletContext();
    		        RequestDispatcher rd = ctx.getRequestDispatcher(sPageAffichage);
    		        rd.forward(request,response);
    		        return;
    	    	}
    		}
    	}
    	else if (sAction.equals("del"))
    	{
    		if (request.getParameter("artRef") != null)
    			panier.enleverAchat(request.getParameter("artRef"));
    	}
    	else if (sAction.equals("modif"))
    	{
        	//Rcupre la liste des articles
        	vArts = panier.donneContenu();

        	for (int i=0;i<vArts.size(); i++)
        		if (request.getParameter(vArts.get(i).getRef()) != null)
        			panier.modifieAchat(vArts.get(i).getRef(), 
        					Integer.parseInt(request.getParameter(vArts.get(i).getRef())));
    	}

    	//
    	// Affiche la liste des articles du panier
    	//
    	//Rcupre la liste des articles
    	vArts = panier.donneContenu();

    	if (!vArts.isEmpty())
    	{
	        request.setAttribute("articles", vArts);
	        request.setAttribute("panierTotal", new Panier(panier.getPrixTotalPanier()));

	        //Si on valide, on affiche le rsum (affichage normal, sans modification)
	    	if (sAction != null)
	    	{
	    		if (sAction.equals("valider"))
	    			sPageAffichage = "/resumePanier.jsp";
		    	else
		    		sPageAffichage = "/contenuPanier.jsp";
	    	}
	    	//Sinon, on affiche le panier et on permet la modification des quantits
	    	else
	    		sPageAffichage = "/contenuPanier.jsp";
    	}
    	else
    	{
	        sPageAffichage = "/panierVide.jsp";
		}

        ServletContext ctx = getServletContext();
        RequestDispatcher rd = ctx.getRequestDispatcher(sPageAffichage);
        rd.forward(request,response);
    }
    
    // <editor-fold defaultstate="collapsed" desc="HttpServlet methods. Click on the + sign on the left to edit the code.">
    /** Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     */
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, IOException
    {
    	this.affArticlesPanier(request, response);
    }
    
    /** Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException
    {
    	this.affArticlesPanier(request, response);
    }

    /** Returns a short description of the servlet.
     */
    public String getServletInfo() {
        return "Gestion du panier";
    }
    // </editor-fold>
}
